@@ -1001,27 +1001,49 @@ def perform_adjustment(
     def add_shrinkage_result_to_guide(each_guide: Guide,
                                         shrinkage_result: ShrinkageResult):
         # NOTE: List[List[float]], first list is each replicate, second list is the monte-carlo samples. We want the mean of the monte-carlo samples next
+
+        
         guide_count_posterior_LFC_samples_normalized_list: List[List[float]] = shrinkage_result.guide_count_posterior_LFC_samples_normalized_list 
+        
+        guide_count_posterior_LFC_samples_normalized_list_rescaled = np.asarray([np.exp(guide_count_posterior_LFC_samples_normalized_list) * ((each_guide.sample_population_normalized_count_reps[rep_i] + each_guide.control_population_normalized_count_reps[rep_i]) * negative_control_guide_control_population_total_normalized_counts_reps[rep_i]) / ((negative_control_guide_sample_population_total_normalized_counts_reps[rep_i] + negative_control_guide_control_population_total_normalized_counts_reps[rep_i]) * each_guide.control_population_normalized_count_reps[rep_i]) for rep_i in replicate_indices])
 
         guide_count_posterior_LFC_samples_normalized_average = np.mean(guide_count_posterior_LFC_samples_normalized_list, axis=0)
+        guide_count_posterior_LFC_samples_normalized_rescaled_average =  np.mean(guide_count_posterior_LFC_samples_normalized_list_rescaled, axis=0)
 
-        LFC_estimate_combined = None
         LFC_estimate_combined_mean = np.mean(guide_count_posterior_LFC_samples_normalized_average)
         LFC_estimate_per_replicate_mean = np.mean(guide_count_posterior_LFC_samples_normalized_list, axis=1)
+
+        LFC_estimate_combined_mean_rescaled = np.mean(guide_count_posterior_LFC_samples_normalized_rescaled_average)
+        LFC_estimate_per_replicate_mean_rescaled = np.mean(guide_count_posterior_LFC_samples_normalized_list_rescaled, axis=1)
         if posterior_estimator.upper() == "MEAN":
             LFC_estimate_combined = LFC_estimate_combined_mean
             LFC_estimate_per_replicate = LFC_estimate_per_replicate_mean
+
+            LFC_estimate_combined_rescaled = LFC_estimate_combined_mean_rescaled
+            LFC_estimate_per_replicate_rescaled = LFC_estimate_per_replicate_mean_rescaled
         elif posterior_estimator.upper() == "MODE":
             LFC_estimate_combined = StatisticalHelperMethods.calculate_map(guide_count_posterior_LFC_samples_normalized_average)
             LFC_estimate_per_replicate =  np.asarray([StatisticalHelperMethods.calculate_map(guide_count_posterior_LFC_samples_normalized) for guide_count_posterior_LFC_samples_normalized in guide_count_posterior_LFC_samples_normalized_list])
 
+            LFC_estimate_combined_rescaled = StatisticalHelperMethods.calculate_map(guide_count_posterior_LFC_samples_normalized_rescaled_average)
+            LFC_estimate_per_replicate_rescaled =  np.asarray([StatisticalHelperMethods.calculate_map(guide_count_posterior_LFC_samples_normalized_rescaled) for guide_count_posterior_LFC_samples_normalized_rescaled in guide_count_posterior_LFC_samples_normalized_list_rescaled])
+
+        ###
         LFC_estimate_combined_CI = StatisticalHelperMethods.calculate_credible_interval(guide_count_posterior_LFC_samples_normalized_average)
         LFC_estimate_combined_std = np.std(guide_count_posterior_LFC_samples_normalized_average)
+        
+        LFC_estimate_combined_CI_rescaled = StatisticalHelperMethods.calculate_credible_interval(guide_count_posterior_LFC_samples_normalized_rescaled_average)
+        LFC_estimate_combined_std_rescaled = np.std(guide_count_posterior_LFC_samples_normalized_rescaled_average)
 
+
+        ##
         LFC_estimate_per_replicate_CI = np.asarray([StatisticalHelperMethods.calculate_credible_interval(guide_count_posterior_LFC_samples_normalized_rep) for guide_count_posterior_LFC_samples_normalized_rep in guide_count_posterior_LFC_samples_normalized_list])
         LFC_estimate_per_replicate_std = np.asarray([np.std(guide_count_posterior_LFC_samples_normalized_rep) for guide_count_posterior_LFC_samples_normalized_rep in guide_count_posterior_LFC_samples_normalized_list])
 
-
+        LFC_estimate_per_replicate_CI_rescaled = np.asarray([StatisticalHelperMethods.calculate_credible_interval(guide_count_posterior_LFC_samples_normalized_rep_rescaled) for guide_count_posterior_LFC_samples_normalized_rep_rescaled in guide_count_posterior_LFC_samples_normalized_list_rescaled])
+        LFC_estimate_per_replicate_std_rescaled = np.asarray([np.std(guide_count_posterior_LFC_samples_normalized_rep_rescaled) for guide_count_posterior_LFC_samples_normalized_rep_rescaled in guide_count_posterior_LFC_samples_normalized_list_rescaled])
+        
+        ##
         LFC_estimate_combined_prob0 = StatisticalHelperMethods.calculate_norm_prob_0(LFC_estimate_combined_mean, LFC_estimate_combined_std)
         LFC_estimate_per_replicate_prob0 = [StatisticalHelperMethods.calculate_norm_prob_0(LFC_estimate_per_replicate_mean[rep_i], LFC_estimate_per_replicate_std[rep_i]) for rep_i in replicate_indices]
 
@@ -1032,6 +1054,19 @@ def perform_adjustment(
         LFC_estimate_per_replicate_gt0 = [StatisticalHelperMethods.calculate_norm_gt_0_mc(guide_count_posterior_LFC_samples_normalized_rep_i) for guide_count_posterior_LFC_samples_normalized_rep_i in guide_count_posterior_LFC_samples_normalized_list]
 
 
+
+        LFC_estimate_combined_prob0_rescaled = StatisticalHelperMethods.calculate_norm_prob_0(LFC_estimate_combined_mean_rescaled, LFC_estimate_combined_std_rescaled)
+        LFC_estimate_per_replicate_prob0_rescaled = [StatisticalHelperMethods.calculate_norm_prob_0(LFC_estimate_per_replicate_mean_rescaled[rep_i], LFC_estimate_per_replicate_std_rescaled[rep_i]) for rep_i in replicate_indices]
+
+        LFC_estimate_combined_prob_lt0_rescaled = StatisticalHelperMethods.calculate_norm_lt_0_mc(guide_count_posterior_LFC_samples_normalized_rescaled_average)
+        LFC_estimate_combined_prob_gt0_rescaled = StatisticalHelperMethods.calculate_norm_gt_0_mc(guide_count_posterior_LFC_samples_normalized_rescaled_average)
+        
+        LFC_estimate_per_replicate_lt0_rescaled = [StatisticalHelperMethods.calculate_norm_lt_0_mc(guide_count_posterior_LFC_samples_normalized_rescaled_rep_i) for guide_count_posterior_LFC_samples_normalized_rescaled_rep_i in guide_count_posterior_LFC_samples_normalized_list_rescaled]
+        LFC_estimate_per_replicate_gt0_rescaled = [StatisticalHelperMethods.calculate_norm_gt_0_mc(guide_count_posterior_LFC_samples_normalized_rescaled_rep_i) for guide_count_posterior_LFC_samples_normalized_rescaled_rep_i in guide_count_posterior_LFC_samples_normalized_list_rescaled]
+
+
+
+
         each_guide.LFC_estimate_combined = LFC_estimate_combined
         each_guide.LFC_estimate_per_replicate = LFC_estimate_per_replicate
 
@@ -1052,6 +1087,29 @@ def perform_adjustment(
         each_guide.guide_count_posterior_LFC_samples_normalized_list = guide_count_posterior_LFC_samples_normalized_list
         each_guide.guide_count_posterior_LFC_samples_normalized_average = guide_count_posterior_LFC_samples_normalized_average
 
+
+
+
+        each_guide.LFC_estimate_combined_rescaled = LFC_estimate_combined_rescaled
+        each_guide.LFC_estimate_per_replicate_rescaled = LFC_estimate_per_replicate_rescaled
+
+        each_guide.LFC_estimate_combined_CI_rescaled = LFC_estimate_combined_CI_rescaled
+        each_guide.LFC_estimate_combined_std_rescaled = LFC_estimate_combined_std_rescaled
+
+        each_guide.LFC_estimate_per_replicate_CI_rescaled = LFC_estimate_per_replicate_CI_rescaled
+        each_guide.LFC_estimate_per_replicate_std_rescaled = LFC_estimate_per_replicate_std_rescaled
+
+        each_guide.LFC_estimate_combined_prob0_rescaled = LFC_estimate_combined_prob0_rescaled
+        each_guide.LFC_estimate_combined_prob_lt0_rescaled = LFC_estimate_combined_prob_lt0_rescaled
+        each_guide.LFC_estimate_combined_prob_gt0_rescaled = LFC_estimate_combined_prob_gt0_rescaled
+
+        each_guide.LFC_estimate_per_replicate_prob0_rescaled = LFC_estimate_per_replicate_prob0_rescaled
+        each_guide.LFC_estimate_per_replicate_lt0_rescaled = LFC_estimate_per_replicate_lt0_rescaled
+        each_guide.LFC_estimate_per_replicate_gt0_rescaled = LFC_estimate_per_replicate_gt0_rescaled
+
+        each_guide.guide_count_posterior_LFC_samples_normalized_list_rescaled = guide_count_posterior_LFC_samples_normalized_list_rescaled
+        each_guide.guide_count_posterior_LFC_samples_normalized_average_rescaled = guide_count_posterior_LFC_samples_normalized_rescaled_average
+
         return each_guide
 
     # Perform final model inference:
@@ -1261,11 +1319,11 @@ if __name__ == "__main__":
         neighborhood_bandwidth = 7,
         neighborhood_imputation_prior_strength = [0.00123287, 0.00126275, 0.00129235],
         neighborhood_imputation_likelihood_strength = [0.05219207, 0.05339028, 0.05260389],
-        singleton_imputation_prior_strength = None,
+        singleton_imputation_prior_strength =  [0.00195427, 0.00178769, 0.00201526],
         deviation_weights = np.asarray([10,10,10]),
         KL_guide_set_weights = None,
-        shrinkage_prior_strength = None,
+        shrinkage_prior_strength = [1.29101373, 1.11547384, 0.3860163],
         posterior_estimator = "mean",
         random_seed = 234,
         cores=10
-    )
\ No newline at end of file
+    ) # LEFTOFF - Fix Bug shown below
\ No newline at end of file
